@@ -19,7 +19,7 @@ logger = logging.getLogger(__name__)
 class Speakeasy(object):
     def __init__(self, host, metric_socket, cmd_port, pub_port, emitter_name,
                  emitter_args=None, emission_interval=60, legacy=None,
-                 hwm=20000):
+                 hwm=20000, socket_mod=None):
         """ Aggregate metrics and emit. Also support live data querying. """
         self.metric_socket = metric_socket
         self.pub_port = pub_port
@@ -61,14 +61,17 @@ class Speakeasy(object):
         # Increase the HWM
         self.recv_socket.set_hwm(hwm)
         self.recv_socket.bind('ipc://{0}'.format(self.metric_socket))
+        if socket_mod:
+            os.chmod(self.metric_socket, socket_mod)
 
         # Listen for commands
         self.cmd_socket = self.context.socket(zmq.REP)
         self.cmd_socket.bind('tcp://*:{0}'.format(self.cmd_port))
 
         # Publish metrics
-        self.pub_socket = self.context.socket(zmq.PUB)
-        self.pub_socket.bind('tcp://*:{0}'.format(self.pub_port))
+        if self.pub_port:
+            self.pub_socket = self.context.socket(zmq.PUB)
+            self.pub_socket.bind('tcp://*:{0}'.format(self.pub_port))
 
         # Register sockets for polling
         self.poller = zmq.Poller()
@@ -175,7 +178,8 @@ class Speakeasy(object):
             return
 
         msg = ujson.dumps(pub_metrics)
-        self.pub_socket.send(msg)
+        if self.pub_port:
+            self.pub_socket.send(msg)
 
     def process_command(self, cmd):
         """ Process command and reply """
@@ -331,6 +335,7 @@ class Speakeasy(object):
             if os.path.exists(self.legacy):
                 logger.info('Cleaning up legacy socket')
                 os.remove(self.legacy)
+        os.remove(self.metric_socket)
 
 
 def import_emitter(name, **kwargs):
